@@ -18,7 +18,9 @@ try {
 tap.test('basic test', function (t) {
   var p = path.resolve(__dirname, '../package.json')
   readJson(p, function (er, data) {
-    if (er) throw er
+    if (er) {
+      throw er
+    }
     basic_(t, data)
   })
 })
@@ -30,16 +32,18 @@ function basic_ (t, data) {
   t.equal(data.name, pkg.name)
   t.type(data.author, 'object')
   t.equal(data.readme, readme)
-  t.deepEqual(data.scripts, pkg.scripts)
+  t.same(data.scripts, pkg.scripts)
   t.equal(data.main, pkg.main)
   t.equal(data.readmeFilename, 'README.md')
 
-  if (isGit) t.similar(data.gitHead, /^[a-f0-9]{40}$/)
+  if (isGit) {
+    t.match(data.gitHead, /^[a-f0-9]{40}$/)
+  }
 
   // optional deps are folded in.
-  t.deepEqual(data.optionalDependencies, pkg.optionalDependencies)
+  t.same(data.optionalDependencies, pkg.optionalDependencies)
   t.has(data.dependencies, pkg.dependencies)
 
-  t.deepEqual(data.devDependencies, pkg.devDependencies)
+  t.same(data.devDependencies, pkg.devDependencies)
   t.end()
 }
