@@ -6,7 +6,7 @@ var p = path.resolve(__dirname, 'fixtures/erroneous.json')
 tap.test('erroneous package data', function (t) {
   readJson(p, function (er, data) {
     t.ok(er instanceof Error)
-    t.ok(er.message.match(/Unexpected token '/))
+    t.ok(er.message.match(/Unexpected token "'" \(0x27\)/))
     t.end()
   })
 })
